"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : new P(function (resolve) { resolve(result.value); }).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
const axios_1 = require("axios");
const loading_1 = require("../loading");
const safe_parse_1 = require("../safe-parse");
const showLoading = (loading, loadingText) => {
    if (loading) {
        loading_1.globalLoading.show(loadingText || '数据加载中...');
    }
};
const hideLoading = (loading) => {
    if (loading) {
        loading_1.globalLoading.hide();
    }
};
exports.fetchData = {
    warning(msg) {
        // tslint:disable-next-line
        console.warn(msg);
    },
    goto(url) {
        window.location.href = url;
    },
    config(data) {
        Object.assign(this, data);
    },
    post({ url, body, loading, loadingText, }) {
        return __awaiter(this, void 0, void 0, function* () {
            try {
                showLoading(loading, loadingText);
                const { data: resData } = yield axios_1.default.post(url, body);
                hideLoading(loading);
                if (loading) {
                    loading_1.globalLoading.hide();
                }
                const { success, data, message } = resData;
                if (success) {
                    return safe_parse_1.safeParse(data);
                }
                if (data === -1 && /^http/.test(message)) {
                    // 未登录
                    this.goto(message);
                }
                else {
                    // 提示报错信息
                    this.warning(message);
                }
                return Promise.reject(data);
            }
            catch (error) {
                const { message } = error;
                if (['Network Error', 'Request failed with status code 500'].indexOf(message) !== -1) {
                    this.warning('网络异常');
                }
                hideLoading(loading);
                return Promise.reject(error);
            }
        });
    },
    get(url) {
        return __awaiter(this, void 0, void 0, function* () {
            const { data } = yield axios_1.default.get(url);
            return data;
        });
    },
};
