"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const add_style_1 = require("../add-style");
const loadingId = 'custom-loading';
exports.globalLoading = {
    /**
     * 私有方法，勿用
     */
    _init() {
        const el = this.el = document.getElementById(loadingId);
        if (el) {
            return el;
        }
        const html = getHtml();
        add_style_1.addStyle(getCss(), 'global-loading');
        const div = document.createElement('div');
        div.id = loadingId;
        div.innerHTML = html;
        document.body.appendChild(div);
        return div;
    },
    /**
     * 私有方法，勿用
     * @param display
     * @param text
     */
    _setDisplay(display, text) {
        const el = this._init();
        if (el) {
            el.style.display = display;
        }
        this.setText(text);
    },
    /**
     * 打开loading效果
     * @param text loading文本
     */
    show(text) {
        this._setDisplay('flex', text);
    },
    /**
     * 关闭loading
     */
    hide() {
        this._setDisplay('none');
    },
    /**
     * 更新文本，持续更新内容调用该方法即可
     * @param text 要更新的文本
     */
    setText(text) {
        const textEl = document.getElementById('global-loading-text');
        if (textEl) {
            textEl.innerText = text;
        }
    },
};
const getHtml = () => `<div class="swapping-squares-spinner" :style="spinnerStyle">
    <div class="square"></div>
    <div class="square"></div>
    <div class="square"></div>
    <div class="square"></div>
  </div>
  <div id="global-loading-text"></div>
  `;
const getCss = (color = '#fff') => `#custom-loading{
    position:fixed;
    top: 0;
    left: 0;
    width: 100vw;
    height: 100vh;
    justify-content: center;
    align-items: center;
    display: flex;
    background:rgba(0,0,0,0.5);
    z-index: 1000;
    flex-direction: column;
  }
  #global-loading-text{
    margin-top: 25px;
    font-size:16px;
    color: #fff;
  }
  .swapping-squares-spinner, .swapping-squares-spinner * {
    box-sizing: border-box;
  }

  .swapping-squares-spinner {
    height: 65px;
    width: 65px;
    position: relative;
    display: flex;
    flex-direction: row;
    justify-content: center;
    align-items: center;
  }

  .swapping-squares-spinner .square {
    height: calc(65px * 0.25 / 1.3);
    width:  calc(65px * 0.25 / 1.3);
    animation-duration: 1000ms;
    border: calc(65px * 0.04 / 1.3) solid ${color};
    margin-right: auto;
    margin-left: auto;
    position: absolute;
    animation-iteration-count: infinite;
  }

  .swapping-squares-spinner .square:nth-child(1) {
    animation-name: swapping-squares-animation-child-1;
    animation-delay: 500ms;
  }

  .swapping-squares-spinner .square:nth-child(2) {
    animation-name: swapping-squares-animation-child-2;
    animation-delay: 0ms;
  }

  .swapping-squares-spinner .square:nth-child(3) {
    animation-name: swapping-squares-animation-child-3;
    animation-delay: 500ms;
  }

  .swapping-squares-spinner .square:nth-child(4) {
    animation-name: swapping-squares-animation-child-4;
    animation-delay: 0ms;
  }

  @keyframes swapping-squares-animation-child-1 {
    50% {
      transform: translate(150%,150%) scale(2,2);
    }
  }

  @keyframes swapping-squares-animation-child-2 {
    50% {
      transform: translate(-150%,150%) scale(2,2);
    }
  }

  @keyframes swapping-squares-animation-child-3 {
    50% {
      transform: translate(-150%,-150%) scale(2,2);
    }
  }

  @keyframes swapping-squares-animation-child-4 {
    50% {
      transform: translate(150%,-150%) scale(2,2);
    }
  }`;
