/**
 * 事件绑定，返回值remove方法可以取消绑定。
 * @param {Element} target 目标dom
 * @param {String} eventType 事件名称
 * @param {Function} callback 回掉
 * @param {Boolean}} useCapture 是否捕获截断监听
 */
export const addEventListener = (target, eventType, callback, useCapture = false) => {
    if (target == null) {
        throw new Error('target 不能为空');
    }
    target.addEventListener(eventType, callback, useCapture);
    return {
        remove() {
            target.removeEventListener(eventType, callback, useCapture);
        },
    };
};
const removeEvent = (event) => {
    if (event && typeof event.remove === 'function') {
        event.remove();
    }
};
/**
 * 移除addEventListener绑定的事件, 支持多个event一起移除
 * @param config addEventListener 返回的数据，或者组成的数组
 */
export const removeEvents = (config) => {
    if (Array.isArray(config)) {
        config.forEach(removeEvent);
    }
    else {
        removeEvent(config);
    }
};
