export const promiseCache = (fnValue, delay) => {
    const cacheResolveFn = [];
    const cacheRejectFn = [];
    let cacheData = null;
    let time = 0;
    const fn = () => {
        return new Promise((resolve, reject) => {
            const now = Date.now();
            // 判断是否需要读取缓存
            if (now - time < delay * 1000) {
                // 如果缓存数据还在请求中，则resolve加入到请求队列中
                if (cacheData) {
                    resolve(cacheData);
                }
                else {
                    cacheResolveFn.push(resolve);
                    cacheRejectFn.push(reject);
                }
            }
            else {
                // 没有命中缓存则调用fn函数，拿到数据，判断队列中是否有待处理的数据
                fnValue()
                    .then((data) => {
                    cacheData = data;
                    resolve(data);
                    runFns(cacheResolveFn, data);
                })
                    .catch((err) => {
                    reject(err);
                    runFns(cacheRejectFn, err);
                });
            }
            time = Date.now();
        });
    };
    // 手动清除缓存数据
    fn.clear = () => {
        cacheData = null;
        time = 0;
    };
    return fn;
};
function runFns(fns, data) {
    if (fns.length > 0) {
        fns.forEach((fnValue) => fnValue(data));
        fns = [];
    }
}
